# Import and plot RNAseq data for Hox genes

# Load matrix data with normalized (TMM) and FPKM relative abundance.
rnaseq_matrix = read.csv("genes.TMM.fpkm.matrix", header = TRUE, sep = "\t")

# Contig names.
hox_contigs <- c(
  "TR24696|c0_g1", # hox1
  "TR41559|c0_g1", # hox2
  "TR41106|c4_g1", # hox3
  "TR35050|c0_g1", # hox4
  "TR8323|c0_g1", # hox5
  "TR16624|c1_g1", # hox6
  "TR20675|c0_g1", # hox7
  "TR13142|c0_g1", # hox8
  "TR13045|c0_g2", # post1
  "TR22236|c0_g1" # post2
)

hox_rows <- c(
  "post2", # TR22236|c0_g1
  "hox2", # TR41559|c0_g1
  "hox6", # TR16624|c1_g1
  "hox1", # TR24696|c0_g1
  "post1", # TR13045|c0_g2
  "hox5", # TR8323|c0_g1
  "hox4", # TR35050|c0_g1
  "hox7", # TR20675|c0_g1
  "hox8", # TR13142|c0_g1
  "hox3" # TR41106|c4_g1
)

f1_cols <- c(
  "Ttra_F1_S01",
  "Ttra_F1_S02",
  "Ttra_F1_S03",
  "Ttra_F1_S04",
  "Ttra_F1_S05",
  "Ttra_F1_S06",
  "Ttra_F1_S07",
  "Ttra_F1_S08",
  "Ttra_F1_S09",
  "Ttra_F1_S10",
  "Ttra_F1_S11",
  "Ttra_F1_S12",
  "Ttra_F1_S13",
  "Ttra_F1_S14"
)

f2_cols <- c(
  "Ttra_F2_S01",
  "Ttra_F2_S02",
  "Ttra_F2_S03",
  "Ttra_F2_S04",
  "Ttra_F2_S05",
  "Ttra_F2_S06",
  "Ttra_F2_S07",
  "Ttra_F2_S08",
  "Ttra_F2_S09",
  "Ttra_F2_S10",
  "Ttra_F2_S11",
  "Ttra_F2_S12",
  "Ttra_F2_S13",
  "Ttra_F2_S14"
)

# Subset Hox genes only.
hox_matrix = subset(rnaseq_matrix, X %in% hox_contigs)
# Apply Hox nomenclature.
row.names(hox_matrix) <- hox_rows
# Combine names.
hox_matrix <- cbind(hox_rows, hox_matrix)
# Order by row names.
hox_matrix <- hox_matrix[order(row.names(hox_matrix)),]

# Subset for Female1.
f1_matrix = subset(hox_matrix, select = f1_cols)
# Subset for Female2.
f2_matrix = subset(hox_matrix, select = f2_cols)

# Export Hox matrices.
write.csv(f1_matrix, file = "f1_matrix.csv")
write.csv(f2_matrix, file = "f2_matrix.csv")

# Import qPCR matrices.
f1_qpcr <- read.csv("f1_qpcr.csv", row.names=1)
f2_qpcr <- read.csv("f2_qpcr.csv", row.names=1)

# Import RNAseq merged.
f1f2_rnaseq <- read.csv("f1f2_rnaseq.csv", row.names=1)
f1f2_qpcr <- read.csv("f1f2_qpcr.csv", row.names=1)

# Load Hox matrix manually transformed to long format (added qPCR data).
hox_long <- read.csv("hox_long.csv", header = TRUE)

# Only keep until stage 09.
hox_long_9 <- subset(hox_long, ! stage %in% c("S10","S11","S12","S13","S14"))

# Load ggplot2.
library(ggplot2)

hox_colors <- c(
  rgb(234, 67, 60, maxColorValue=255),
  rgb(239, 137, 65, maxColorValue=255),
  rgb(247, 232, 67, maxColorValue=255),
  rgb(157, 203, 82, maxColorValue=255),
  rgb(86, 166, 174, maxColorValue=255),
  rgb(128, 209, 235, maxColorValue=255),
  rgb(50, 68, 155, maxColorValue=255),
  rgb(246, 173, 120, maxColorValue=255),
  rgb(27, 117, 187, maxColorValue=255),
  rgb(60, 89, 131, maxColorValue=255)
)

# Plot comparison of RNAseq and qPCR expression profiles.
pdf("rnaseq_vs_qpcr.pdf", width = 8.27, height = 11.69)
plot_rnaseq <- ggplot(data = hox_long_9, aes(x = stage, y = fpkm, color = gene, group = female)) + scale_color_manual(values = hox_colors) + geom_line(lwd = 1) + geom_point(size = 2) + facet_grid(gene ~ female, scales = "free") + theme(legend.position="none", axis.text.x = element_text(size=9), axis.text.y = element_text(size=9)) + ggtitle("RNAseq") + scale_x_discrete(labels=c("1", "2", "3", "4", "5", "6", "7", "8", "9"))
plot_qpcr <- ggplot(data = hox_long_9, aes(x = stage, y = au, color = gene, group = female)) + scale_color_manual(values = hox_colors) + geom_line(lwd = 1) + geom_point(size = 2) + facet_grid(gene ~ female, scales = "free") + theme(legend.position="none", axis.text.x = element_text(size=9), axis.text.y = element_text(size=9)) + ggtitle("qPCR") + scale_x_discrete(labels=c("1", "2", "3", "4", "5", "6", "7", "8", "9"))
multiplot(plot_rnaseq, plot_qpcr, cols=2)
dev.off()

# Plot as heatmaps.
pheatmap::pheatmap(f1f2_rnaseq, scale = "none", cluster_rows = FALSE, cluster_cols = FALSE, gaps_row = 10, main = "RNAseq (FPKM)", filename = "rnaseq_heatmap.pdf")
pheatmap::pheatmap(f1f2_qpcr, scale = "none", cluster_rows = FALSE, cluster_cols = FALSE, gaps_row = 10, main = "qPCR (AU)", filename = "qpcr_heatmap.pdf")


## Other unused plots.

# Subset by female.
hox_long_f1 <- subset(hox_long, female == "F1")
hox_long_f2 <- subset(hox_long, female == "F2")

# Plot Hox expression profiles.
pdf("hox_profiling.pdf", width = 8.27, height = 11.69)
f1hox_rnaseq <- ggplot(data = hox_long_f1, aes(x = stage, y = fpkm, fill = gene)) + scale_fill_manual(values = hox_colors) + geom_bar(stat = "identity", position = "dodge") + theme(axis.text.x = element_text(size=9), axis.text.y = element_text(size=9)) + ggtitle("Female 1")
#f1hox_qpcr <- ggplot(data = hox_long_f1, aes(x = stage, y = au, fill = gene)) + scale_fill_manual(values = hox_colors) + geom_bar(stat = "identity", position = "dodge") + theme(axis.text.x = element_text(size=9), axis.text.y = element_text(size=9)) + ggtitle("Female 1 qPCR Hox profiles")
f2hox_rnaseq <- ggplot(data = hox_long_f2, aes(x = stage, y = fpkm, fill = gene)) + scale_fill_manual(values = hox_colors) + geom_bar(stat = "identity", position = "dodge") + theme(axis.text.x = element_text(size=9), axis.text.y = element_text(size=9)) + ggtitle("Female 2")
#f2hox_qpcr <- ggplot(data = hox_long_f2, aes(x = stage, y = au, fill = gene)) + scale_fill_manual(values = hox_colors) + geom_bar(stat = "identity", position = "dodge") + theme(axis.text.x = element_text(size=9), axis.text.y = element_text(size=9)) + ggtitle("Female 2 qPCR Hox profiles")
#multiplot(f1hox_rnaseq, f2hox_rnaseq, f1hox_qpcr, f2hox_qpcr, rows=4)
multiplot(f1hox_rnaseq, f2hox_rnaseq, rows=2)
dev.off()

# Plot Hox expression profiles.
pdf("hox_lines.pdf", width = 8.27, height = 5.85)
ggplot() + geom_line(data = hox_long_f1, size = 1, alpha = 0.8, aes(x = stage, y = fpkm, color = gene, group = gene)) + geom_line(data = hox_long_f2, size = 1, alpha = 0.8, aes(x = stage, y = fpkm, color = gene, group = gene)) + scale_color_manual(values = hox_colors) + ggtitle("Females 1 and 2 RNAseq Hox profiles")
dev.off()

# Plot heatmaps with neatmap (tentative).
pdf("hox_heatmap.pdf", width = 8.27, height = 11.69)
h1 <- heatmap1(f1_matrix, row.order = order(rownames(f1_matrix)), column.order = order(colnames(f1_matrix)), column.labels = colnames(f1_matrix), row.labels = rownames(f1_matrix)) + scale_fill_gradient2(low="white", high="black") + scale_x_continuous(expand = c(0, .5)) + scale_y_continuous(expand = c(.1, 0))
h2 <- heatmap(f2_matrix, row.order = order(rownames(f2_matrix)), column.order = order(colnames(f2_matrix)), column.labels = colnames(f2_matrix), row.labels = rownames(f2_matrix)) + scale_fill_gradient2(low="white", high="black") + scale_x_continuous(expand = c(0, .5)) + scale_y_continuous(expand = c(.1, 0))
multiplot(h1, h2, rows=2)
dev.off()
